'From Squeak3.6gamma of 11 September 2003 [latest update: #5420] on 15 September 2003 at 2:29:59 pm'!
"Change Set:		Chronology-h-Tests-NewGeneration
Date:			24 August 2003
Author:			Brent Pinkney

This is an optional changeset to test the new generation Chronology classes.
It can be used to test the temporary TDate,TTime and TTimeSpan classes"!

ClassTestCase subclass: #TimespanTest
	instanceVariableNames: 'timespan '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Kernel-Chronology-Tests'!
ClassTestCase subclass: #YearTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Kernel-Chronology-Tests'!

!DateTest methodsFor: 'Tests' stamp: 'brp 8/23/2003 16:07'!
testAccessing

	self	
		assert: date day = 153;
		assert: date julianDayNumber = 2441836;
		assert: date leap = 0;
		assert: date monthIndex = 6;
		assert: date monthName = #June;
		assert: date weekday = #Saturday;
		assert: date weekdayIndex = 7;
		assert: date year = 1973.
! !

!DateTest methodsFor: 'Tests' stamp: 'brp 8/23/2003 16:06'!
testGeneralInquiries

	| shuffled indices names now | 

	shuffled := #(#January #February #March #April #May #June #July 
					#August #September #October #November #December) shuffled.
	indices := shuffled collect: [ :m | self dateClass indexOfMonth: m ].
	names := indices collect: [ :i | self dateClass nameOfMonth: i ].
	self assert: names = shuffled.

	shuffled := #(#Monday #Tuesday #Wednesday #Thursday #Friday #Saturday #Sunday) shuffled.
	indices := shuffled collect: [ :m | self dateClass dayOfWeek: m ].
	names := indices collect: [ :i | self dateClass nameOfDay: i ].
	self assert: names = shuffled.
	
	now  := self dateClass dateAndTimeNow.
	self 
		assert: now size = 2;
		assert: now first = self dateClass today.

	self assert: (self dateClass firstWeekdayOfMonth: #June year: 1973) = 7.

	self
		assert: (self dateClass leapYear: 1973) = 0;
		assert: (self dateClass leapYear: 1972) = 1;
		assert: (self dateClass daysInYear: 1973) = 365;
		assert: (self dateClass daysInYear: 1972) = 366;
		assert: (self dateClass daysInMonth: #February forYear: 1973) = 28;
		assert: (self dateClass daysInMonth: #February forYear: 1972) = 29.
! !

!DateTest methodsFor: 'Private' stamp: 'brp 8/24/2003 00:10'!
dateClass

	^ Date! !


!MonthTest methodsFor: 'Tests' stamp: 'brp 8/23/2003 16:08'!
testInquiries

	self 
		assert: month index = 7;
		assert: month name = #July;
		assert: month duration = (31 days).
! !


!TimeStampTest methodsFor: 'Tests' stamp: 'brp 8/23/2003 15:24'!
testComparing

	| ts1 ts2 ts3 c1 c2 le |
	ts1 := self timestampClass date: ('01-10-2000' asDate) time: ('11:55:00 am' asTime).
	ts2 := self timestampClass date: ('07-26-2003' asDate) time: ('22:09:45 am' asTime).
	ts3 := self timestampClass date: ('05-28-1972' asDate) time: ('04:31:14 pm' asTime).

	self
		assert: ts1 = timestamp;
		assert: ts1 hash = timestamp hash;
		assert: timestamp = timestamp copy;
		assert: ts1 < ts2;
		deny: ts1 < ts3.

	c1 := self timestampClass current.
	c2 := self timestampClass current.
	le _ (c1 < c2).
	self assert: le.

! !

!TimeStampTest methodsFor: 'Tests' stamp: 'brp 8/23/2003 15:02'!
testFromString
	"This should signal an exception in 3.6beta as Time>>fromString: does not exist."

	self should: [ timestamp = (self timestampClass fromString: '1-10-2000 11:55:00 am') ] 

! !

!TimeStampTest methodsFor: 'Tests' stamp: 'brp 8/23/2003 14:52'!
testInstanceCreation

	self 
		should: [ self timestampClass midnight asDuration = (0 hours) ];
		should: [ self timestampClass midnightOn: timestamp date ] 
			raise: Deprecation;
		should: [ self timestampClass noon asDuration = (12 hours) ];
		should: [ self timestampClass noonOn: timestamp date ] 
			raise: Deprecation.! !

!TimeStampTest methodsFor: 'Tests' stamp: 'brp 8/23/2003 15:02'!
testPrinting

	self	
		assert: timestamp printString = '10 January 2000 11:55 am'.
! !

!TimeStampTest methodsFor: 'Private' stamp: 'brp 7/27/2003 13:50'!
timestampClass

	^ TimeStamp! !


!TimeTest methodsFor: 'Tests' stamp: 'brp 8/23/2003 22:27'!
testPrinting

	self	
		assert: time printString = '4:02:47 am';
		assert: time intervalString =  '4 hours 2 minutes 47 seconds';
		assert: time print24 = '04:02:47';
		assert: time printMinutes = '4:02 am';
		assert: time hhmm24 = '0402'.
! !

!TimeTest methodsFor: 'Private' stamp: 'brp 7/27/2003 13:32'!
timeClass

	^ Time! !


!TimespanTest methodsFor: 'Tests' stamp: 'brp 9/15/2003 14:22'!
testAccessing

	self 
		assert: (timespan start =
				 (DateAndTime year: 2003 month: 03 day: 22 hour: 12 minute: 0 second: 0));
		assert: timespan duration = (Duration hours: 100)

! !

!TimespanTest methodsFor: 'Tests' stamp: 'brp 9/15/2003 14:29'!
testArithmetic

	| ts1 ts2 d |
	ts1 _ timespan + 2 days.
	ts2 _ ts1 - 2 days.
	d _ ts1 - (DateAndTime year: 2003 month: 03 day: 20).

	self 
		assert: (ts1 start = 
				 (DateAndTime year: 2003 month: 03 day: 24 hour: 12 minute: 0 second: 0));
		assert: (ts1 duration = timespan duration);
		assert: (ts2 start = timespan start);
		assert: (ts2 duration = timespan duration).

	self
		assert: d = (Duration days: 4 hours: 12 minutes: 0 seconds: 0)

! !

!TimespanTest methodsFor: 'Running' stamp: 'brp 9/15/2003 14:20'!
setUp
	"100 hours starting noon 22 March 2003"


	timespan _ Timespan 
				starting: 
					(DateAndTime year: 2003 month: 03 day: 22 hour: 12 minute: 0 second: 0)
				duration: 
					(Duration hours: 100)
! !

!TimespanTest methodsFor: 'Running' stamp: 'brp 9/15/2003 14:20'!
tearDown

	timespan _ nil
! !

!TimespanTest methodsFor: 'Coverage' stamp: 'brp 9/15/2003 14:15'!
classToBeTested

	^ Timespan
! !


!WeekTest methodsFor: 'Tests' stamp: 'brp 8/23/2003 16:08'!
testInquiries

	self
		assert: week firstDate = '29 June 1998' asDate;
		assert: week lastDate = '5 July 1998' asDate;
		assert: week index = 5;
		assert: week duration = (7 days).
! !


!YearTest methodsFor: 'Tests' stamp: 'brp 9/11/2003 14:30'!
testCurrent

	| yyyy |

	yyyy _ DateAndTime now year.
	
	self assert: Year current start = (DateAndTime year: yyyy month: 1 day: 1)! !

!YearTest methodsFor: 'Coverage' stamp: 'brp 9/11/2003 14:31'!
classToBeTested

	^ Year! !

